@@ -313,6 +313,7 @@ class CausalSparseAttention(nn.Module):
         self.attn_topk = config.attn_topk
         self.short_sequence_criteria = config.short_sequence_criteria
         # kv cache management
+        self.enable_kv_cache_management = config.enable_kv_cache_management # whether to enable kv cache management
         self.max_kv_cache_size = config.max_kv_cache_size # condition that trigger the cache management
         self.kv_cache_window_size = config.kv_cache_window_size # observation window size
         self.min_kv_cache_size = config.min_kv_cache_size # minimum kv cache size
@@ -368,12 +369,12 @@ class CausalSparseAttention(nn.Module):
         assert x.size(1) == 1, "sequence length must be 1"
         C = x.size(-1)
         q, k, v = self.receptance(x), self.key(x), self.value(x)
-        # manage k, v cache, only when not use full attention
-        if self.deocoding_attn_mode != 'full' and k_cache.size(1) > self.max_kv_cache_size:
+        # manage k, v cache
+        if self.enable_kv_cache_management and k_cache.size(1) > self.max_kv_cache_size:
             k_cache, v_cache = self.update_kv_cache(q, k_cache, v_cache)
         CT = k_cache.size(1)
         # apply the attention, only decoding consider the full attention mode
-        if CT <= self.short_sequence_criteria or self.deocoding_attn_mode == 'full': # for short sequence, use full attention
+        if CT <= self.short_sequence_criteria or self.decoding_attn_mode == 'full': # for short sequence, use full attention
             k_cache = torch.cat((k_cache, k), dim=1) # update k cache
             v_cache = torch.cat((v_cache, v), dim=1) # update v cache
             q = q.view(1, 1, self.n_head, C // self.n_head).transpose(1, 2) # (1, 1, C) -> (1, nh, 1, hs)
@@ -425,8 +426,8 @@ class CausalSparseAttention(nn.Module):
         if len(x.shape) == 2:
             x = x.unsqueeze(0) # (T, C) -> (1, T, C)
         B, T, C = x.size()
-        # manage k, v cache, only when not use full attention
-        if self.attn_mode != 'full' and k_cache.size(1) > self.max_kv_cache_size:
+        # manage k, v cache
+        if self.enable_kv_cache_management and k_cache.size(1) > self.max_kv_cache_size:
             k_cache, v_cache = self.update_kv_cache(x, k_cache, v_cache)
         CT = k_cache.size(1) # cache seq length
         # apply the attention
@@ -547,11 +548,12 @@ class RWKV_X_Config:
     attn_chunk_size: int = 2000
     attn_topk: int = 3
     short_sequence_criteria: int = 8000 # if sequence length <= this, use full attention
+    enable_kv_cache_management: bool = False # whether to enable kv cache management
     max_kv_cache_size: int = 20000
     kv_cache_window_size: int = 2000
     min_kv_cache_size: int = 16000
     prefill_attn_mode: str = 'chunk' # 'chunk' or 'full'
-    deocoding_attn_mode: str = 'full' # 'full' or 'snapKV' or 'new'
+    decoding_attn_mode: str = 'full' # 'full' or 'snapKV' or 'new'
 
 class RWKV_X(nn.Module):
     def __init__(self, model_path, strategy, config=None):
@@ -605,9 +607,10 @@ class RWKV_X(nn.Module):
                 n_embd=n_embd,
                 attn_chunk_size=config.attn_chunk_size,
                 attn_topk=config.attn_topk,
+                enable_kv_cache_management=config.enable_kv_cache_management,
                 max_kv_cache_size=config.max_kv_cache_size,
                 prefill_attn_mode=config.prefill_attn_mode,
-                deocoding_attn_mode=config.deocoding_attn_mode,
+                decoding_attn_mode=config.decoding_attn_mode,
                 short_sequence_criteria=config.short_sequence_criteria,
                 kv_cache_window_size=config.kv_cache_window_size,
                 min_kv_cache_size=config.min_kv_cache_size,
